==> cscec5b-xell-impl-3.0.1-20240315.030900-73-sources.jar: com/ejianc/business/wzxt/service/impl/ReviewDetailServiceImpl.java <==
package com.ejianc.business.wzxt.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.wzxt.vo.CauseDetailVO;
import com.ejianc.business.wzxt.vo.CheckVO;
import com.ejianc.business.wzxt.vo.PlanVO;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.wzxt.mapper.ReviewDetailMapper;
import com.ejianc.business.wzxt.bean.ReviewDetailEntity;
import com.ejianc.business.wzxt.service.IReviewDetailService;

import java.util.List;

/**
 * 复核详情实体
 *
 * @author generator
 *
 */
@Service("reviewDetailService")
public class ReviewDetailServiceImpl extends BaseServiceImpl<ReviewDetailMapper, ReviewDetailEntity> implements IReviewDetailService{

    @Override
    public List<CauseDetailVO> queryStandingBook(Page<CauseDetailVO> page, QueryWrapper queryWrapper) {
        return baseMapper.queryStandingBook(page, queryWrapper);
    }

    @Override
    public List<CauseDetailVO> queryStandingBookExport(QueryWrapper queryWrapper) {
        return baseMapper.queryStandingBookExport(queryWrapper);
    }

    @Override
    public List<PlanVO> queryPlanInfo(Long projectId, Long wbsId, Long materialId) {
        return baseMapper.queryPlanInfo(projectId, wbsId, materialId);
    }

    @Override
    public List<CheckVO> queryCheckInfo(Long projectId, Long wbsId, Long materialId) {
        return baseMapper.queryCheckInfo(projectId, wbsId, materialId);
    }


}

==> cscec5b-xell-impl-3.0.1-20250407.033944-86-sources.jar: com/ejianc/business/wzxt/service/impl/ReviewDetailServiceImpl.java <==
package com.ejianc.business.wzxt.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.wzxt.vo.CauseDetailVO;
import com.ejianc.business.wzxt.vo.CheckVO;
import com.ejianc.business.wzxt.vo.PlanVO;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.wzxt.mapper.ReviewDetailMapper;
import com.ejianc.business.wzxt.bean.ReviewDetailEntity;
import com.ejianc.business.wzxt.service.IReviewDetailService;

import java.util.List;

/**
 * 复核详情实体
 *
 * @author generator
 *
 */
@Service("reviewDetailService")
public class ReviewDetailServiceImpl extends BaseServiceImpl<ReviewDetailMapper, ReviewDetailEntity> implements IReviewDetailService{

    @Override
    public List<CauseDetailVO> queryStandingBook(Page<CauseDetailVO> page, QueryWrapper queryWrapper) {
        return baseMapper.queryStandingBook(page, queryWrapper);
    }

    @Override
    public List<CauseDetailVO> queryStandingBookExport(QueryWrapper queryWrapper) {
        return baseMapper.queryStandingBookExport(queryWrapper);
    }

    @Override
    public List<PlanVO> queryPlanInfo(Long projectId, Long wbsId, Long materialId) {
        return baseMapper.queryPlanInfo(projectId, wbsId, materialId);
    }

    @Override
    public List<CheckVO> queryCheckInfo(Long projectId, Long wbsId, Long materialId) {
        return baseMapper.queryCheckInfo(projectId, wbsId, materialId);
    }

    @Override
    public List<CauseDetailVO> queryProjectReport(Page<CauseDetailVO> page, QueryWrapper wrapper) {
        return baseMapper.queryProjectReport(page, wrapper);
    }

    @Override
    public List<CauseDetailVO> queryReportList(Page<CauseDetailVO> page, QueryWrapper wrapper) {
        return baseMapper.queryReportList(page, wrapper);
    }


}
